<?php

namespace Cdsxz\Dsd\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Cdsxz\Dsd\Http\Requests\AXT021AdminRequest;
use Cdsxz\Dsd\Interfaces\AXT021RepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class AXT021AdminController extends AdminController
{
    /**
     * Initialize a_x_t-021 controller.
     *
     * @param type AXT021RepositoryInterface $a_x_t-021
     *
     * @return type
     */
    public function __construct(AXT021RepositoryInterface $a_x_t-021)
    {
        $this->model = $a_x_t-021;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AXT021AdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('dsd.a_x_t-021.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('dsd::a_x_t-021.names').' :: ');

        return $this->theme->of('dsd::admin.a_x_t-021.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(AXT021AdminRequest $request, $id)
    {
        $a_x_t-021 = $this->model->find($id);

        if (empty($a_x_t-021)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('dsd::admin.a_x_t-021.new');
        }

        if ($request->wantsJson()) {
            return $a_x_t-021;
        }

        Former::populate($a_x_t-021);

        return view('dsd::admin.a_x_t-021.show', compact('a_x_t-021'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AXT021AdminRequest $request)
    {
        $a_x_t-021 = $this->model->findOrNew(0);
        Former::populate($a_x_t-021);

        return view('dsd::admin.a_x_t-021.create', compact('a_x_t-021'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AXT021AdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $a_x_t-021 = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('dsd::a_x_t-021.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(AXT021AdminRequest $request, $id)
    {
        $a_x_t-021 = $this->model->find($id);

        Former::populate($a_x_t-021);

        return view('dsd::admin.a_x_t-021.edit', compact('a_x_t-021'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(AXT021AdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $a_x_t-021 = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('dsd::a_x_t-021.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AXT021AdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('dsd::a_x_t-021.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
